@@ -21,6 +21,7 @@ enum lttng_condition_type {
 	LTTNG_CONDITION_TYPE_BUFFER_USAGE_LOW = 102,
 	LTTNG_CONDITION_TYPE_SESSION_ROTATION_ONGOING = 103,
 	LTTNG_CONDITION_TYPE_SESSION_ROTATION_COMPLETED = 104,
+	LTTNG_CONDITION_TYPE_EVENT_RULE_MATCHES = 105,
 };
 
 enum lttng_condition_status {
@@ -29,6 +30,7 @@ enum lttng_condition_status {
 	LTTNG_CONDITION_STATUS_UNKNOWN = -2,
 	LTTNG_CONDITION_STATUS_INVALID = -3,
 	LTTNG_CONDITION_STATUS_UNSET = -4,
+	LTTNG_CONDITION_STATUS_UNSUPPORTED = -5,
 };
 
 /*
