@@ -15,10 +15,11 @@
 #include "lttng-ust-ctl.h"
 
 int context_kernel_add(struct ltt_kernel_session *ksession,
-		const struct lttng_event_context *ctx, char *channel_name);
+		const struct lttng_event_context *ctx,
+		const char *channel_name);
 int context_ust_add(struct ltt_ust_session *usess,
 		enum lttng_domain_type domain,
 		const struct lttng_event_context *ctx,
-		char *channel_name);
+		const char *channel_name);
 
 #endif /* _LTT_CONTEXT_H */
