@@ -17,8 +17,14 @@
 #define KERN_MODULES_MAJOR         2
 #define KERN_MODULES_MINOR         0
 
+enum kernel_module_property_load_policy {
+	KERNEL_MODULE_PROPERTY_LOAD_POLICY_REQUIRED = 0,
+	KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL = 1,
+};
+
 struct kern_modules_param {
 	char *name;
+    enum kernel_module_property_load_policy load_policy;
 	bool loaded;
 };
 
