@@ -28,6 +28,41 @@
 
 /* LTTng kernel tracer mandatory core modules list */
 struct kern_modules_param kern_modules_control_core[] = {
+	{
+		.name = (char *) "lttng_wrapper",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_statedump",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_uprobes",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_kprobes",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_kretprobes",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_clock",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_OPTIONAL,
+		.loaded = false,
+	},
+	{
+		.name = (char *) "lttng_lib_ring_buffer",
+		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_REQUIRED,
+		.loaded = false,
+	},
 	{
 		.name = (char *) "lttng-ring-buffer-client-discard",
 		.load_policy = KERNEL_MODULE_PROPERTY_LOAD_POLICY_REQUIRED,
