@@ -41,8 +41,8 @@ static void *thread_application_notification(void *data)
 	rcu_register_thread();
 	rcu_thread_online();
 
-	health_register(health_sessiond,
-		HEALTH_SESSIOND_TYPE_APP_MANAGE_NOTIFY);
+	health_register(the_health_sessiond,
+			HEALTH_SESSIOND_TYPE_APP_MANAGE_NOTIFY);
 
 	if (testpoint(sessiond_thread_app_manage_notify)) {
 		goto error_testpoint;
@@ -185,7 +185,7 @@ error_testpoint:
 		health_error();
 		ERR("Health error occurred in %s", __func__);
 	}
-	health_unregister(health_sessiond);
+	health_unregister(the_health_sessiond);
 	rcu_thread_offline();
 	rcu_unregister_thread();
 	return NULL;
