@@ -1,18 +1,8 @@
 /*
- * Copyright (C) 2017 - Jérémie Galarneau <jeremie.galarneau@efficios.com>
+ * Copyright (C) 2017 Jérémie Galarneau <jeremie.galarneau@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License, version 2 only,
- * as published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef LTTNG_SESSIOND_CONFIG_H
@@ -39,6 +29,9 @@ struct sessiond_config {
 	int verbose_consumer;
 	/* Agent TCP port range for registration. Used by the agent thread. */
 	struct config_int_range agent_tcp_port;
+
+	int event_notifier_buffer_size_kernel;
+	int event_notifier_buffer_size_userspace;
 	/* Socket timeout for receiving and sending (in seconds). */
 	int app_socket_timeout;
 
