@@ -3,7 +3,9 @@
  *
  * The "inih" library is distributed under the New BSD license:
  *
- * Copyright (c) 2009, Brush Technology - All rights reserved.
+ * Copyright (C) 2009 Brush Technology - All rights reserved.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -180,6 +182,10 @@ int ini_parse_file(FILE* file, ini_entry_handler handler, void* user)
 				 * Valid name[=:]value pair found, call
 				 * handler
 				 */
+				if (strlen(name) >= sizeof(prev_name)) {
+					/* Truncation occurs, report an error. */
+					error = lineno;
+				}
 				strncpy0(prev_name, name, sizeof(prev_name));
 				if (handler(user, section, name, value) < 0 &&
 					!error) {
