@@ -442,7 +442,7 @@ static struct lttng_event *lttng_event_rule_jul_logging_generate_lttng_event(
 			rule, &log_level_rule);
 	if (status == LTTNG_EVENT_RULE_STATUS_UNSET) {
 		loglevel_type = LTTNG_EVENT_LOGLEVEL_ALL;
-		loglevel_value = 0;
+		loglevel_value = LTTNG_LOGLEVEL_JUL_ALL;
 	} else if (status == LTTNG_EVENT_RULE_STATUS_OK) {
 		enum lttng_log_level_rule_status llr_status;
 
