@@ -1,18 +1,8 @@
 /*
- * Copyright (C) 2012 - David Goulet <dgoulet@efficios.com>
+ * Copyright (C) 2012 David Goulet <dgoulet@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License, version 2 only, as
- * published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define _LGPL_SOURCE
@@ -24,13 +14,13 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <errno.h>
 #include <fcntl.h>
 #include <common/compat/time.h>
 #include <poll.h>
 
 #include <common/common.h>
 #include <common/time.h>
+#include <common/compat/errno.h>
 
 #include "inet.h"
 
@@ -376,18 +366,31 @@ ssize_t lttcomm_recvmsg_inet_sock(struct lttcomm_sock *sock, void *buf,
 		len_last = iov[0].iov_len;
 		ret = recvmsg(sock->fd, &msg, flags);
 		if (ret > 0) {
+			if (flags & MSG_DONTWAIT) {
+				goto end;
+			}
 			iov[0].iov_base += ret;
 			iov[0].iov_len -= ret;
 			assert(ret <= len_last);
 		}
 	} while ((ret > 0 && ret < len_last) || (ret < 0 && errno == EINTR));
+
 	if (ret < 0) {
+		if (errno == EAGAIN && flags & MSG_DONTWAIT) {
+			/*
+			 * EAGAIN is expected in non-blocking mode and should
+			 * not be reported as an error. Moreover, if no data
+			 * was read, 0 must not be returned as it would be
+			 * interpreted as an orderly shutdown of the socket.
+			 */
+			goto end;
+		}
 		PERROR("recvmsg inet");
 	} else if (ret > 0) {
 		ret = len;
 	}
 	/* Else ret = 0 meaning an orderly shutdown. */
-
+end:
 	return ret;
 }
 
