@@ -14,13 +14,13 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <errno.h>
 #include <fcntl.h>
 #include <common/compat/time.h>
 #include <poll.h>
 
 #include <common/common.h>
 #include <common/time.h>
+#include <common/compat/errno.h>
 
 #include "inet6.h"
 
