@@ -43,7 +43,6 @@ size_t utils_get_current_time_str(const char *format, char *dst, size_t len);
 int utils_get_group_id(const char *name, bool warn, gid_t *gid);
 char *utils_generate_optstring(const struct option *long_options,
 		size_t opt_count);
-int utils_create_lock_file(const char *filepath);
 int utils_recursive_rmdir(const char *path);
 int utils_truncate_stream_file(int fd, off_t length);
 int utils_show_help(int section, const char *page_name, const char *help_msg);
@@ -54,6 +53,9 @@ enum lttng_error_code utils_user_id_from_name(
 		const char *user_name, uid_t *user_id);
 enum lttng_error_code utils_group_id_from_name(
 		const char *group_name, gid_t *group_id);
+enum lttng_error_code utils_get_cpu_count(unsigned int *count);
+enum lttng_error_code utils_check_enough_available_memory(
+		uint64_t num_bytes_requested, uint64_t *num_bytes_available);
 
 /*
  * Parse `str` as an unsigned long long value.
